@@ -600,7 +600,7 @@ Documening for POD::Coverage tests, Moose stuff.
 
 =head1 AUTHOR
 
-Cory 'G' Watson <gphat@cpan.org>
+Cory G Watson <gphat@cpan.org>
 
 =head1 SEE ALSO
 
