@@ -172,7 +172,7 @@ Prepare this DataSet.
 
 =head1 AUTHOR
 
-Cory 'G' Watson <gphat@cpan.org>
+Cory G Watson <gphat@cpan.org>
 
 =head1 LICENSE
 
