@@ -162,7 +162,7 @@ Set the alpha value for the renderer, which makes things more or less opaque.
 
 =head1 AUTHOR
 
-Cory 'G' Watson <gphat@cpan.org>
+Cory G Watson <gphat@cpan.org>
 
 =head1 SEE ALSO
 
