@@ -180,7 +180,7 @@ Set/Get the alpha value to make each bar more or less opaque.
 
 =head1 AUTHOR
 
-Cory 'G' Watson <gphat@cpan.org>
+Cory G Watson <gphat@cpan.org>
 
 =head1 SEE ALSO
 
